import logging
import typing as t

from rich.logging import RichHandler
from rich import print
import typer

from horbach_cli import __version__
from horbach_cli.libs.common import log_lvl_callback, LOG_LVL
from horbach_cli import converter, deduplicator

app = typer.Typer(rich_markup_mode="markdown")


def version_callback(value: bool):
    version = __version__
    if value:
        print(f":speech_balloon: h-cli Version: {version}")
        raise typer.Exit()


@app.callback()
def main(
    verbose: str = typer.Option(
        "INFO", "--verbose", "-v", callback=log_lvl_callback, help=f":mag: `LOG_LEVEL` one of: {', '.join(LOG_LVL)}"
    ),
    version: t.Optional[bool] = typer.Option(None, "--version", callback=version_callback, is_eager=True),
):
    logging.basicConfig(
        level=verbose, format="%(message)s", datefmt="[%X]", handlers=[RichHandler(rich_tracebacks=True)]
    )


app.add_typer(converter.app, name="converter", help=":rocket: manipulates files and etc.", rich_help_panel="Hacks")
app.add_typer(
    deduplicator.app, name="dedub", help=":two_men_holding_hands: dedublicates something.", rich_help_panel="Hacks"
)

if __name__ == "__main__":
    app(prog_name="h-cli")



import subprocess
import logging

import typer
from rich import print

from horbach_cli.libs.converter import convert_images_to_pdf

app = typer.Typer()


@app.command(help=":camera: images into :memo: pdf")
def img_to_pdf(
    images_folder: str = typer.Argument(..., help="Path to folder with images"),
    pdf_file: str = typer.Argument("result.pdf", help="Result file name"),
):
    convert_images_to_pdf(images_folder, pdf_file)


@app.command(help=":camera: images from :green_apple: heic to jpg")
def heic_to_jpg(images_folder: str = typer.Argument(..., help="Path to folder with images")):
    cmd = f"magick mogrify -monitor -format jpg {images_folder}/*.HEIC {images_folder}/*.heic"
    result = subprocess.run(cmd.split(), capture_output=True, text=True)
    print(":tada: converting has finished")
    logging.debug(result.stderr)


if __name__ == "__main__":
    app()



import os
import logging

from PIL import Image


def convert_images_to_pdf(images_folder: str, pdf_file: str) -> None:
    images = []
    allowed_formats = (".jpg", ".png", ".jpeg")
    files = os.listdir(images_folder)
    files.sort()
    logging.info(f"Files in the {images_folder} -> {files}")
    for file in files:
        logging.debug(f"Processing with {file}")
        if file.endswith(allowed_formats):
            image = Image.open(os.path.join(images_folder, file))
            if image.mode == "RGBA":
                image = image.convert("RGB")
            images.append(image)
    images[0].save(f"{images_folder}/{pdf_file}", save_all=True, append_images=images[1:])



import typer

LOG_LVL = [
    "DEBUG",
    "INFO",
    "WARNING",
    "ERROR",
    "CRITICAL",
]


def log_lvl_callback(value: str):
    lvls = [lvl.lower() for lvl in LOG_LVL]
    lvls.extend(LOG_LVL)
    if value not in lvls:
        raise typer.BadParameter(f"Only {LOG_LVL} are allowed")
    return value



import logging
from pathlib import Path
import typing as t
import os

import typer
from rich import print
from rich.prompt import Confirm

from difPy import dif

app = typer.Typer()


@app.command(help="deal with dublicated :camera: images")
def img_dedub(
    dirs: t.List[Path] = typer.Argument(..., help="Path to dirs with images"),
    delete: bool = False,
):
    search = dif(dirs, recursive=True)

    for entry in search.result:
        entry_payload = search.result[entry]

        origin = entry_payload["location"]
        print(f":floppy_disk: origin -> {origin}")

        dublicates = list()
        for d in entry_payload["matches"]:
            dublicates.append(entry_payload["matches"][d]["location"])
        print(f"dublicates: {dublicates}")

        if delete and Confirm.ask(":skull: Are you sure want to delete duplicates?"):
            for d in dublicates:
                logging.info(f"Deleting: {d}")
                os.remove(d)


if __name__ == "__main__":
    app()
